pub struct ConfigSettings {
pub channel: Option<String>,
pub emulated_form_factor: Option<String>,
pub form_factor: Option<String>,
pub locale: Option<String>,
pub only_categories: Option<Value>,
}Expand description
Message containing the configuration settings for the Lighthouse run.
This type is not used in any activity, and only used as part of another schema.
Fields
channel: Option<String>How Lighthouse was run, e.g. from the Chrome extension or from the npm module.
emulated_form_factor: Option<String>The form factor the emulation should use. This field is deprecated, form_factor should be used instead.
form_factor: Option<String>How Lighthouse should interpret this run in regards to scoring performance metrics and skipping mobile-only tests in desktop.
locale: Option<String>The locale setting.
only_categories: Option<Value>List of categories of audits the run should conduct.