pub struct Environment {
pub benchmark_index: Option<f64>,
pub credits: Option<HashMap<String, String>>,
pub host_user_agent: Option<String>,
pub network_user_agent: Option<String>,
}Expand description
Message containing environment configuration for a Lighthouse run.
This type is not used in any activity, and only used as part of another schema.
Fields
benchmark_index: Option<f64>The benchmark index number that indicates rough device class.
credits: Option<HashMap<String, String>>The version of libraries with which these results were generated. Ex: axe-core.
host_user_agent: Option<String>The user agent string of the version of Chrome used.
network_user_agent: Option<String>The user agent string that was sent over the network.