pub struct LhrEntity {
pub category: Option<String>,
pub homepage: Option<String>,
pub is_first_party: Option<bool>,
pub is_unrecognized: Option<bool>,
pub name: Option<String>,
pub origins: Option<Vec<String>>,
}Expand description
Message containing an Entity.
This type is not used in any activity, and only used as part of another schema.
Fields
category: Option<String>Optional. An optional category name for the entity.
homepage: Option<String>Optional. An optional homepage URL of the entity.
is_first_party: Option<bool>Optional. An optional flag indicating if the entity is the first party.
is_unrecognized: Option<bool>Optional. An optional flag indicating if the entity is not recognized.
name: Option<String>Required. Name of the entity.
origins: Option<Vec<String>>Required. A list of URL origin strings that belong to this entity.