pub struct PagespeedApiLoadingExperienceV5 {
pub id: Option<String>,
pub initial_url: Option<String>,
pub metrics: Option<HashMap<String, UserPageLoadMetricV5>>,
pub origin_fallback: Option<bool>,
pub overall_category: Option<String>,
}Expand description
The CrUX loading experience object that contains CrUX data breakdowns.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The url, pattern or origin which the metrics are on.
initial_url: Option<String>The requested URL, which may differ from the resolved “id”.
metrics: Option<HashMap<String, UserPageLoadMetricV5>>The map of .
origin_fallback: Option<bool>True if the result is an origin fallback from a page, false otherwise.
overall_category: Option<String>The human readable speed “category” of the id.